

[Back to main file](README.md)

Used references for Tableau-Hyper-Management
============================================

| Category                | Reference Name and URL                                                                                                                                                                                                                                                                                                 | No.  |
| ----------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---- |
| GetText                 | [Official Website](https://www.gnu.org/software/gettext/)                                                                                                                                                                                                                                                              | #1   |
| GetText                 | [Releases](https://github.com/oscarotero/Gettext/releases)                                                                                                                                                                                                                                                             | #2   |
| GetText                 | [Utilities](https://www.gnu.org/software/gettext/manual/html_node/index.html)                                                                                                                                                                                                                                          | #3   |
| Git                     | [About](https://git-scm.com/about)                                                                                                                                                                                                                                                                                     | #4   |
| Git                     | [Book](https://git-scm.com/book/en/v2)                                                                                                                                                                                                                                                                                 | #5   |
| Git                     | [Cheat Sheet](https://services.github.com/on-demand/downloads/github-git-cheat-sheet.pdf)                                                                                                                                                                                                                              | #6   |
| Git                     | [Cheat Sheet from Atlassian](https://www.google.com/url?sa=t&rct=j&q=&esrc=s&source=web&cd=10&cad=rja&uact=8&ved=2ahUKEwiL37Sx8tHdAhVBDywKHQHfDBgQFjAJegQIChAC&url=https%3A%2F%2Fwww.atlassian.com%2Fdam%2Fjcr%3A8132028b-024f-4b6b-953e-e68fcce0c5fa%2Fatlassian-git-cheatsheet.pdf&usg=AOvVaw2TdLUeHteS2YU_G9u_-6nP) | #7   |
| Git                     | [Cheat Sheet from GitLab](https://about.gitlab.com/images/press/git-cheat-sheet.pdf)                                                                                                                                                                                                                                   | #8   |
| Git                     | [Documentation/Reference](https://git-scm.com/doc)                                                                                                                                                                                                                                                                     | #9   |
| Git                     | [Documentation for Log](https://git-scm.com/docs/git-log)                                                                                                                                                                                                                                                              | #10  |
| Git                     | [Official Website](https://git-scm.com/)                                                                                                                                                                                                                                                                               | #11  |
| Git                     | [Releases](https://github.com/git-for-windows/git/releases/)                                                                                                                                                                                                                                                           | #12  |
| Git                     | [Set up an SSH key](https://confluence.atlassian.com/bitbucket/set-up-an-ssh-key-728138079.html)                                                                                                                                                                                                                       | #13  |
| Git                     | [Smart Ways to Correct Mistakes in Git](https://css-tricks.com/the-smart-ways-to-correct-mistakes-in-git/)                                                                                                                                                                                                             | #14  |
| JSON                    | [JavaScript Object Notation](http://json.org/)                                                                                                                                                                                                                                                                         | #15  |
| Mark Down               | [Bitbucket Supported Markdown](https://bitbucket.org/tutorials/markdowndemo)                                                                                                                                                                                                                                           | #16  |
| Mark Down               | [GitHub Guides for Mastering](https://guides.github.com/features/mastering-markdown/)                                                                                                                                                                                                                                  | #17  |
| MySQL Server            | [MySQL 5.6 Reference Manual](https://dev.mysql.com/doc/refman/5.6/en/)                                                                                                                                                                                                                                                 | #18  |
| MySQL Server            | [MySQL 5.7 Reference Manual](https://dev.mysql.com/doc/refman/5.7/en/)                                                                                                                                                                                                                                                 | #19  |
| MySQL Server            | [MySQL 8.0 Reference Manual](https://dev.mysql.com/doc/refman/8.0/en/)                                                                                                                                                                                                                                                 | #20  |
| MySQL Server            | [MySQL Server Community Edition](https://www.mysql.com/products/community/)                                                                                                                                                                                                                                            | #21  |
| Python                  | [Building and Distributing Packages with Setuptools](https://setuptools.readthedocs.io/en/latest/setuptools.html)                                                                                                                                                                                                      | #22  |
| Python                  | [How to Host your Python Package on PyPI with GitHub](https://www.codementor.io/arpitbhayani/host-your-python-package-using-github-on-pypi-du107t7ku)                                                                                                                                                                  | #23  |
| Python                  | [How to Structure Software Projects: Python Example](http://queirozf.com/entries/how-to-structure-software-projects-python-example)                                                                                                                                                                                    | #24  |
| Python                  | [Programming in the Eclipse IDE](https://www.ics.uci.edu/~pattis/common/handouts/introtopythonineclipse/)                                                                                                                                                                                                              | #25  |
| Python                  | [PyDev](http://www.pydev.org/)                                                                                                                                                                                                                                                                                         | #26  |
| Python                  | [PyDev Manual Installation Steps](http://www.pydev.org/manual_101_install.html)                                                                                                                                                                                                                                        | #27  |
| Python                  | [Python 3 Subprocess Examples](http://queirozf.com/entries/python-3-subprocess-examples)                                                                                                                                                                                                                               | #28  |
| Python                  | [Python Best Practices for More Pythonic Code](https://realpython.com/tutorials/best-practices/)                                                                                                                                                                                                                       | #29  |
| Python                  | [Python Examples](https://pythonexamples.org/)                                                                                                                                                                                                                                                                         | #30  |
| Python                  | [Python For Beginners](https://www.python.org/about/gettingstarted/)                                                                                                                                                                                                                                                   | #31  |
| Python                  | [Python Programming Guides and Tutorials](https://www.pythoncentral.io/)                                                                                                                                                                                                                                               | #32  |
| Python                  | [Python Vs PHP: What's the Difference?](https://www.guru99.com/python-vs-php.html)                                                                                                                                                                                                                                     | #33  |
| Python                  | [Python vs. PHP in 2019](https://hackr.io/blog/python-vs-php-in-2019)                                                                                                                                                                                                                                                  | #34  |
| Python - package Babel  | [GitHub repository](https://github.com/python-babel/babel)                                                                                                                                                                                                                                                             | #35  |
| Python - package Babel  | [Official documentation website](http://babel.pocoo.org/en/latest/)                                                                                                                                                                                                                                                    | #36  |
| Python - package Pandas | [Mutate for Pandas Dataframes: Examples with Assign](http://queirozf.com/entries/mutate-for-pandas-dataframes-examples-with-assign)                                                                                                                                                                                    | #37  |
| Python - package Pandas | [Pandas Dataframe Examples: Column Operations](http://queirozf.com/entries/pandas-dataframe-examples-column-operations)                                                                                                                                                                                                | #38  |
| Python - package Pandas | [Pandas Dataframe Examples: Manipulating Date and Time](http://queirozf.com/entries/pandas-dataframe-examples-manipulating-date-and-time)                                                                                                                                                                              | #39  |
| Python - package Pandas | [Pandas Dataframe Examples: String Functions](http://queirozf.com/entries/pandas-dataframe-examples-string-functions)                                                                                                                                                                                                  | #40  |
| Python - package Pandas | [Pandas DataFrame: GroupBy Examples](http://queirozf.com/entries/pandas-dataframe-groupby-examples)                                                                                                                                                                                                                    | #41  |
| Python - package Pandas | [Pandas Dataframe: Replace Examples](http://queirozf.com/entries/pandas-dataframe-replace-examples)                                                                                                                                                                                                                    | #42  |
| Python - package Pandas | [Pandas Dataframe: Union and Concat Examples](http://queirozf.com/entries/pandas-dataframe-union-and-concat-examples)                                                                                                                                                                                                  | #43  |
| Python - package Pandas | [Pandas Examples: Creating and Initializing DataFrames](http://queirozf.com/entries/pandas-examples-creating-and-initializing-dataframes)                                                                                                                                                                              | #44  |
| Python - package Pandas | [Pandas Indexing Examples: Accessing and Setting Values on DataFrames](http://queirozf.com/entries/pandas-indexing-examples-accessing-and-setting-values-on-dataframes)                                                                                                                                                | #45  |
| Python - package Pandas | [Pandas Time Series Examples: DatetimeIndex, PeriodIndex and TimedeltaIndex](http://queirozf.com/entries/pandas-time-series-examples-datetimeindex-periodindex-and-timedeltaindex)                                                                                                                                     | #46  |
| Python - package Pandas | [Using SQL-like Syntax with Pandas Dataframe: Query and Eval Examples](http://queirozf.com/entries/using-sql-like-syntax-with-pandas-dataframe-query-and-eval-examples)                                                                                                                                                | #47  |
| SAP HANA                | [Database Client - ODBC Connection Properties](https://help.sap.com/viewer/0eec0d68141541d1b07893a39944924e/2.0.02/en-US/7cab593774474f2f8db335710b2f5c50.html)                                                                                                                                                        | #48  |
| SAP HANA                | [Reference - System Tables and Monitor Views](http://sap.optimieren.de/hana/hana/html/monitor_views.html)                                                                                                                                                                                                              | #49  |
| SAP HANA                | [SQL Functions - Datetime Functions](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/209f228975191014baed94f1b69693ae.html)                                                                                                                                                                  | #50  |
| SAP HANA                | [SQL Functions - JSON Functions](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/5848028bcd364d9aa0706ae1d7ab4184.html)                                                                                                                                                                      | #51  |
| SAP HANA                | [SQL Functions - Window Functions](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/20a353327519101495dfd0a87060a0d3.html)                                                                                                                                                                    | #52  |
| SAP HANA                | [SQL and System Views Reference](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/b4b0eec1968f41a099c828a4a6c8ca0f.html)                                                                                                                                                                      | #53  |
| SAP HANA                | [SQL and System Views Reference - Alphabetical List Of Functions](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/f12b86a6284c4aeeb449e57eb5dd3ebd.html)                                                                                                                                     | #54  |
| SAP HANA                | [SQL and System Views Reference - System Views Reference](https://help.sap.com/viewer/4fe29514fd584807ac9f2a04f6754767/2.0.03/en-US/20cbb10c75191014b47ba845bfe499fe.html)                                                                                                                                             | #55  |
| SAP HANA                | [Version Check](https://answers.sap.com/questions/161894/hana-version-check.html)                                                                                                                                                                                                                                      | #56  |
| SAP HANA                | [Versions Release and History of Evolution](https://www.stechies.com/about-sap-erp-solution-different-versions/)                                                                                                                                                                                                       | #57  |
| Tableau                 | [6 tips to make your dashboards more performant](https://www.tableau.com/about/blog/2016/1/5-tips-make-your-dashboards-more-performant-48574?__src=liftigniter&__widget=blog-widget&li_source=LI&li_medium=blog-widget)                                                                                                | #58  |
| Tableau                 | [Add Annotations](https://onlinehelp.tableau.com/current/pro/desktop/en-us/annotations_annotations_add.htm)                                                                                                                                                                                                            | #59  |
| Tableau                 | [Annotations Tutorial](https://www.tutorialgateway.org/tableau-annotations/)                                                                                                                                                                                                                                           | #60  |
| Tableau                 | [Custom Views](https://onlinehelp.tableau.com/current/pro/desktop/en-us/customview.htm)                                                                                                                                                                                                                                | #61  |
| Tableau                 | [Quick Guide to Annotations in Tableau](https://interworks.com/blog/ekreitler/2016/08/11/quick-guide-annotations-tableau)                                                                                                                                                                                              | #62  |
| Tableau                 | [Doughnut Charts Creation in Tableau](https://kb.tableau.com/articles/issue/creating-donut-charts)                                                                                                                                                                                                                     | #63  |
| Tableau                 | [Geographic Drill Down](https://vizpainter.com/another-tableau-mapping-tip-geographic-drill-down-to-lower-levels-of-detail/)                                                                                                                                                                                           | #64  |
| Tableau                 | [Javascript API: Documentation](https://onlinehelp.tableau.com/current/api/js_api/en-us/JavaScriptAPI/js_api.htm#)                                                                                                                                                                                                     | #65  |
| Tableau                 | [Javascript API: Samples](https://github.com/tableau/js-api-samples)                                                                                                                                                                                                                                                   | #66  |
| Tableau                 | [Javascript API: Tips and Tricks](https://www.youtube.com/watch?v=0xXUYj4WCiU&list=PL_qx68DwhYA8e_z9k7uoRw0zayoY35nUJ&index=4)                                                                                                                                                                                         | #67  |
| Tableau                 | [Products Downloads and Release Notes](https://www.tableau.com/support/releases)                                                                                                                                                                                                                                       | #68  |
| Tableau                 | [Send Data-Driven Alerts from Tableau Online or Tableau Server](https://onlinehelp.tableau.com/current/pro/desktop/en-us/data_alerts.htm)                                                                                                                                                                              | #69  |
| Tableau                 | [Swap Measures Using Parameters](https://onlinehelp.tableau.com/current/pro/desktop/en-us/parameters_swap.htm)                                                                                                                                                                                                         | #70  |
| Tableau                 | [TabCmd Commands](https://onlinehelp.tableau.com/current/server/en-us/tabcmd_cmd.htm)                                                                                                                                                                                                                                  | #71  |
| Tableau                 | [Tabcmd for Generating a PDF of a Tableau View and Emailing](https://kb.tableau.com/articles/howto/tabcmd-for-generating-a-pdf-and-emailing)                                                                                                                                                                           | #72  |
| Tableau                 | [Tableau Extensions API](https://tableau.github.io/)                                                                                                                                                                                                                                                                   | #73  |
| Tableau                 | [Embedding Views & JavaScript API Usage](https://tableau.github.io/embedding-playbook/pages/01_embedding_and_jsapi)                                                                                                                                                                                                    | #74  |
| Tableau                 | [Tableau Hyper API](https://help.tableau.com/current/api/hyper_api/en-us/)                                                                                                                                                                                                                                             | #75  |
| Tableau                 | [Tableau Server Client (Python)](https://tableau.github.io/server-client-python/)                                                                                                                                                                                                                                      | #76  |
| Tableau                 | [What's New in Tableau (only 2019.1)](https://help.tableau.com/v2019.1/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                         | #77  |
| Tableau                 | [What's New in Tableau (only 2019.2)](https://help.tableau.com/v2019.2/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                         | #78  |
| Tableau                 | [What's New in Tableau (only 2019.3)](https://help.tableau.com/v2019.3/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                         | #79  |
| Tableau                 | [What's New in Tableau (only 2019.4)](https://help.tableau.com/v2019.4/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                         | #80  |
| Tableau                 | [What's New in Tableau (only 2020.1)](https://help.tableau.com/v2020.1/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                         | #81  |
| Tableau                 | [What's New in Tableau (up to 2018.3)](https://help.tableau.com/v2018.3/pro/desktop/en-us/whatsnew_desktop.htm)                                                                                                                                                                                                        | #82  |
